- Visão geral
- Requisitos
- Pré-instalação
- Preparação da instalação
- Baixando os pacotes de instalação
- Configuração do registro compatível com OCI
- Concessão de permissões de instalação
- Instalação e configuração do service mesh
- Instalando e configurando a ferramenta GitOps
- Instalando o operador de segredos externos no Kubernetes
- Aplicação de configurações diversas
- Executando o uipathctl
- Instalação
- Pós-instalação
- Migração e atualização
- Monitoramento e alertas
- Administração de cluster
- Configuração específica do produto
- Configuração avançada do Orchestrator
- Configuração de parâmetros do Orchestrator
- Configuração do AppSettings
- Configuração do tamanho máximo da solicitação
- Substituição da configuração de armazenamento no nível do cluster
- Configuração do NLog
- Salvando logs do robô no Elasticsearch
- Configuração dos repositórios de credenciais
- Configuração da chave de criptografia por tenant
- Limpeza do banco de dados do Orchestrator
- Ignorar a instalação da biblioteca do host
- AI Trust Layer
- Solução de problemas
- Falha no provisionamento do AI Center após a atualização para a 2023.10 ou posterior
- Volumes do Insights criados em duas zonas diferentes após a migração
- Falha de atualização devido aos tamanhos de PVC do Insights substituídos
- Os componentes de backup do Velero permanecem após a atualização no AKS do Automation Suite 2024.10.x
- A configuração de backup não funciona devido a uma falha na conexão com o Azure Government
- Pods no namespace uipath travaram ao habilitar taints de nó personalizado
- Não é possível iniciar o Automation Hub e o Apps com configuração de proxy
- O backup do Velero falha com o erro FailedValidation
- Solução de problemas de segredos externos
- Solução de problemas de Temporal como um serviço
- Os pods do AI Center e do Document Understanding falham ao iniciar com a verificação do certificado TLS habilitada
- Erros de validação de certificado TLS
- O Fluentd não exporta logs em ambientes IPv6
- O Studio Desktop não pode carregar conectores e atividades do Integration Service
- Migreção manual do ArgoCD NetworkPolicy (GHSA-47m3-95c7-g2g8)
- Configuração de solicitações e limites de recursos para cargas de trabalho criadas pelo uipathctl
Substituição da configuração de armazenamento no nível do cluster
Substitua a classe de armazenamento e a configuração de armazenamento no nível do cluster no Automation Suite no EKS/AKS.
O Orchestrator é compatível com as seguintes configurações de armazenamento:
- Configuração de armazenamento no nível do cluster
- Configuração de armazenamento no nível do Orchestrator
Recomendamos usar a configuração ao nível do cluster emparelhada com o armazenamento externo. Isso permite que o Orchestrator detecte e use automaticamente as configurações, eliminando a necessidade de configuração adicional.
Configuração de buckets de armazenamento do Azure/Amazon S3
Para configurar o provedor de armazenamento no nível do Orchestrator, atualize os parâmetros do Orchestrator seguindo as seguintes etapas. Para obter detalhes, consulte Configuração de parâmetros do Orchestrator.
-
No arquivo de configuração, em
orchestrator, adicione a seçãolegacy_storage_providerque contém o tipo de armazenamento e a string de conexão, conforme mostrado no exemplo a seguir:"orchestrator": { "enabled": true, "legacy_object_storage": { "type": "Azure", "connection_string": "DefaultEndpointsProtocol=https;AccountName=usr;AccountKey=...;EndpointSuffix=core.windows.net" } }"orchestrator": { "enabled": true, "legacy_object_storage": { "type": "Azure", "connection_string": "DefaultEndpointsProtocol=https;AccountName=usr;AccountKey=...;EndpointSuffix=core.windows.net" } } -
Defina o provedor desejado usando o parâmetro
type. Os valores possíveis são:Azure,AWSeMinio. Algumas considerações:- Os valores do parâmetro
storage.typediferenciam maiúsculas de minúsculas. - A configuração de armazenamento
FileSystemnão é compatível.
- Os valores do parâmetro
-
Adicione a string de conexão para o provedor de armazenamento usando o parâmetro
connection_string. Para obter detalhes sobre o formato das strings de conexão, consulte a seçãoStorage.Locationdo UiPath.Orchestrator.dll.config.
O acesso do navegador da web do Orchestrator a buckets de armazenamento do Amazon e do Azure pode ser restrito devido à política de mesma origem no lado do provedor. Para acessar com êxito o conteúdo de um desses buckets, você deve configurar o respectivo provedor para permitir solicitações de origem cruzada do Orchestrator. Para obter instruções, consulte Configuração do CORS/CSP.
Carregando arquivos para o armazenamento
Os arquivos podem ser carregados para o armazenamento usando a ferramenta de linha de comando uipathctl . Para fazê-lo, use o seguinte comando:
uipathctl config orchestrator upload [parameters]
uipathctl config orchestrator upload [parameters]
| Parâmetro | Description |
|---|---|
--storage-directory <string> | Localização do diretório de armazenamento no disco local. |
--nlog-extensions-directory <string> | Localização das extensões do NLog no disco local. |
--securestore-plugins-directory <string> | Localização dos plug-ins do armazenamento seguro no disco local. |
--is-external-storage | Indica se o armazenamento é externo ou não. |
--namespace <string> | O namespace no qual o Automation Suite está implantado. O valor padrão é uipath. |
-h, --help | Fornece ajuda para o comando de upload. |
Se você usar uma configuração de armazenamento externo no nível do cluster, você deve indicar isso incluindo o parâmetro --is-external-storage ao usar o comando.
Considerações sobre upload de armazenamento
O diretório especificado usando o parâmetro --storage-directory deve conter pelo menos um subdiretório. Todos os subdiretórios são copiados para o armazenamento.
Os arquivos que são carregados na pasta raiz usando --storage-directory são ignorados.
Armazenamento interno
Os subdiretórios são copiados diretamente no bucket usando o nome do subdiretório como o caminho.
Armazenamento externo
- Se o subdiretório tiver o nome de
orchestrator-host, seu conteúdo será copiado para o caminhoOrchestrator-Host. - Se o subdiretório tiver o nome de
orchestrator-<name>, seu conteúdo será copiado para o caminhoO<name>. - Em todos os outros casos, o conteúdo do subdiretório é copiado para o caminho
<name>.
Exemplos de uso
-
Carregando arquivos para o armazenamento:
uipathctl config orchestrator upload --storage-directory /path/to/storage/directoryuipathctl config orchestrator upload --storage-directory /path/to/storage/directory -
Carregando extensões do NLog para o armazenamento:
uipathctl config orchestrator upload --nlog-extensions-directory /path/to/nlog/extensions/directoryuipathctl config orchestrator upload --nlog-extensions-directory /path/to/nlog/extensions/directory -
Fazendo upload de plug-ins de armazenamento seguro para o armazenamento:
uipathctl config orchestrator upload --securestore-plugins-directory /path/to/securestore/plugins/directoryuipathctl config orchestrator upload --securestore-plugins-directory /path/to/securestore/plugins/directory -
Carregando arquivos para o armazenamento externo:
uipathctl config orchestrator upload --is-external-storage --storage-directory /path/to/storage/directoryuipathctl config orchestrator upload --is-external-storage --storage-directory /path/to/storage/directory -
Carregando extensões do NLog para armazenamento externo:
uipathctl config orchestrator upload --is-external-storage --nlog-extensions-directory /path/to/nlog/extensions/directoryuipathctl config orchestrator upload --is-external-storage --nlog-extensions-directory /path/to/nlog/extensions/directory -
Como carregar plug-ins de armazenamento seguro para o armazenamento externo:
uipathctl config orchestrator upload --is-external-storage --securestore-plugins-directory /path/to/securestore/plugins/directoryuipathctl config orchestrator upload --is-external-storage --securestore-plugins-directory /path/to/securestore/plugins/directory